/*******************************************************************\

Module:

Author: CM Wintersteiger

Date:

\*******************************************************************/


#ifndef CPROVER_UTIL_GET_BASE_NAME_H
#define CPROVER_UTIL_GET_BASE_NAME_H

#include <string>

std::string get_base_name(const std::string &in, bool strip_suffix);

#endif // CPROVER_UTIL_GET_BASE_NAME_H
